%define anolis_release 2

Name:             ipset
Version:          7.17
Release:          %{anolis_release}%{?dist}
Summary:          Manage Linux IP sets
License:          GPLv2
URL:              https://ipset.netfilter.org
Source0:          https://ipset.netfilter.org/%{name}-%{version}.tar.bz2
Source1:          ipset.service
Source2:          ipset.start-stop

BuildRequires:    make pkgconfig(bash-completion) pkgconfig(libmnl) >= 1 libtool-ltdl-devel

Requires:         %{name}-libs = %{EVR}

%description
IP sets are a framework inside the Linux kernel since version 2.4.x, which can
be administered by the ipset utility. Depending on the type, currently an IP
set may store IP addresses, (TCP/UDP) port numbers or IP addresses with MAC
addresses in a way, which ensures lightning speed when matching an entry
against a set.

%package libs
Summary:       Shared library providing the IP sets functionality

%description libs
This package provides the libraries which provide the IP sets funcionality.

%package devel
Summary:       Development files for %{name}
Requires:      %{name}-libs = %{EVR}

%description devel
This package provides the files required to develop software using the %{name}
libraries.

%package service
Summary:          %{name} service for %{name}s
Requires:         %{name} = %{EVR}
BuildRequires:    systemd
Requires:         iptables-services
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
BuildArch:        noarch

%description service
This package provides the service %{name} that is split
out of the base package since it is not active by default.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package provides documentation files for %{name}.

%prep
%autosetup

%build
%configure --disable-static \
	--enable-bashcompl \
	--with-kmod=no \
	--without-included-ltdl \
	--enable-settype-modules \
	--with-settype-modules-list="all"
%make_build

%install
%make_install

mkdir -p -m 755 %{buildroot}/%{_unitdir}
mkdir -p -m 755 %{buildroot}%{_libexecdir}/%{name}
install -c -m 644 %{SOURCE1} %{buildroot}/%{_unitdir}
install -c -m 755 %{SOURCE2} %{buildroot}%{_libexecdir}/%{name}

mkdir -p %{buildroot}%{_sysconfdir}/%{name}

%generate_compatibility_deps

%preun
if [[ $1 -eq 0 && -n $(lsmod | grep "^xt_set ") ]]; then
    rmmod xt_set 2>/dev/null
    [[ $? -ne 0 ]] && echo Current iptables configuration requires ipsets && exit 1
fi


%post service
%systemd_post %{name}.service

%preun service
if [[ $1 -eq 0 && -n $(lsmod | grep "^xt_set ") ]]; then
    rmmod xt_set 2>/dev/null
    [[ $? -ne 0 ]] && echo Current iptables configuration requires ipsets && exit 1
fi
%systemd_preun %{name}.service

%postun service
%systemd_postun_with_restart %{name}.service

%files
%{_sbindir}/ipset
%{_sbindir}/ipset-translate
%{_libdir}/ipset
%{_datadir}/bash-completion/completions/ipset
%{_mandir}/man8/*
%{abidir}/ipset-option.list
%{abidir}/ipset*.dump
%license COPYING

%files libs
%dir %{abidir}
%license COPYING
%{_libdir}/libipset.so.13*
%{abidir}/libipset.dump

%files devel
%{_libdir}/libipset.so
%{_libdir}/pkgconfig/libipset.pc
%{_includedir}/libipset
%{_mandir}/man3/libipset.3.*

%files service
%dir %{_sysconfdir}/ipset
%dir %{_libexecdir}/ipset
%attr(0755,root,root) %{_libexecdir}/ipset/ipset.start-stop
%{_unitdir}/ipset.service

%files doc
%doc ChangeLog

%changelog
* Fri Apr 14 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 7.17-2
- Refactor the specfile

* Mon Jan 2 2023 Funda Wang <fundawang@yeah.net> - 7.17-1
- New version 7.17
- Build modules as shared libs rather than statically linked

* Wed Oct 26 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 7.15-3
- optimise spec file

* Thu Sep 29 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 7.15-2
- add doc package

* Thu Mar 10 2022 Mingyue Zhao <wb-zmy745940@alibaba-inc.com> - 7.15-1
- Init for Anolis OS 23
